Struct FixSessionParametersProxy
pub struct FixSessionParametersProxy {
pub allow_unknown: bool,
pub validate_on_modify: bool,
/* private fields */
}Expand description
Session parameter configuration builder
Fields
allow_unknown: boolAllow unknown parameters during validation
validate_on_modify: boolValidate parameters on modification
Implementations
impl FixSessionParametersProxy
impl FixSessionParametersProxy
pub fn new() -> Self
pub fn new() -> Self
Create a new empty session parameters
pub fn get_unknown(&self) -> FixSessionParametersProxy
pub fn get_unknown(&self) -> FixSessionParametersProxy
Get unknown properties
pub fn with_host(self, value: impl Into<String>) -> Self
pub fn with_port(self, value: u32) -> Self
pub fn with_hbi(self, value: u32) -> Self
pub fn listen_address(&self) -> Option<String>
pub fn listen_address(&self) -> Option<String>
Listen address (for acceptor sessions)
pub fn with_listen_address(self, value: impl Into<String>) -> Self
pub fn listen_port(&self) -> Option<u32>
pub fn listen_port(&self) -> Option<u32>
Listen port (for acceptor sessions)
pub fn with_listen_port(self, value: u32) -> Self
pub fn parser_version(&self) -> Option<String>
pub fn parser_version(&self) -> Option<String>
Parser version/dictionary name
pub fn with_parser_version(self, value: impl Into<String>) -> Self
pub fn custom_logon_message_file_name(&self) -> Option<String>
pub fn custom_logon_message_file_name(&self) -> Option<String>
Custom logon message file name
pub fn with_custom_logon_message_file_name( self, value: impl Into<String>, ) -> Self
pub fn custom_logon_message(&self) -> Option<String>
pub fn custom_logon_message(&self) -> Option<String>
Custom logon message
pub fn with_custom_logon_message(self, value: impl Into<String>) -> Self
pub fn with_ssl(self, value: bool) -> Self
pub fn ssl_protocols(&self) -> Option<i32>
pub fn ssl_protocols(&self) -> Option<i32>
SSL protocols bitmask
pub fn with_ssl_protocols(self, value: i32) -> Self
pub fn ssl_ciphers_list(&self) -> Option<String>
pub fn ssl_ciphers_list(&self) -> Option<String>
SSL ciphers list
pub fn with_ssl_ciphers_list(self, value: impl Into<String>) -> Self
pub fn ssl_ca_certificate(&self) -> Option<String>
pub fn ssl_ca_certificate(&self) -> Option<String>
SSL CA certificate path
pub fn with_ssl_ca_certificate(self, value: impl Into<String>) -> Self
pub fn ssl_certificate(&self) -> Option<String>
pub fn ssl_certificate(&self) -> Option<String>
SSL certificate path
pub fn with_ssl_certificate(self, value: impl Into<String>) -> Self
pub fn ssl_certificate_password(&self) -> Option<String>
pub fn ssl_certificate_password(&self) -> Option<String>
SSL certificate password
pub fn with_ssl_certificate_password(self, value: impl Into<String>) -> Self
pub fn ssl_private_key(&self) -> Option<String>
pub fn ssl_private_key(&self) -> Option<String>
SSL private key path
pub fn with_ssl_private_key(self, value: impl Into<String>) -> Self
pub fn ssl_private_key_password(&self) -> Option<String>
pub fn ssl_private_key_password(&self) -> Option<String>
SSL private key password
pub fn with_ssl_private_key_password(self, value: impl Into<String>) -> Self
pub fn ssl_validate_peer_certificate(&self) -> Option<bool>
pub fn ssl_validate_peer_certificate(&self) -> Option<bool>
Validate peer certificate
pub fn with_ssl_validate_peer_certificate(self, value: bool) -> Self
pub fn sender_sub_id(&self) -> Option<String>
pub fn sender_sub_id(&self) -> Option<String>
SenderSubID (tag 142)
pub fn with_sender_sub_id(self, value: impl Into<String>) -> Self
pub fn target_sub_id(&self) -> Option<String>
pub fn target_sub_id(&self) -> Option<String>
TargetSubID (tag 57)
pub fn with_target_sub_id(self, value: impl Into<String>) -> Self
pub fn sender_location_id(&self) -> Option<String>
pub fn sender_location_id(&self) -> Option<String>
SenderLocationID (tag 142)
pub fn with_sender_location_id(self, value: impl Into<String>) -> Self
pub fn target_location_id(&self) -> Option<String>
pub fn target_location_id(&self) -> Option<String>
TargetLocationID (tag 143)
pub fn with_target_location_id(self, value: impl Into<String>) -> Self
pub fn with_user_name(self, value: impl Into<String>) -> Self
pub fn with_password(self, value: impl Into<String>) -> Self
pub fn new_password(&self) -> Option<String>
pub fn new_password(&self) -> Option<String>
New password (tag 925)
pub fn with_new_password(self, value: impl Into<String>) -> Self
pub fn user_name_tag(&self) -> Option<u32>
pub fn user_name_tag(&self) -> Option<u32>
Username tag (default 553)
pub fn with_user_name_tag(self, value: u32) -> Self
pub fn password_tag(&self) -> Option<u32>
pub fn password_tag(&self) -> Option<u32>
Password tag (default 554)
pub fn with_password_tag(self, value: u32) -> Self
Hide logon credentials in logs
pub fn reset_seq_num_on_non_graceful_termination(&self) -> Option<bool>
pub fn reset_seq_num_on_non_graceful_termination(&self) -> Option<bool>
Reset sequence numbers on non-graceful termination
pub fn with_reset_seq_num_on_non_graceful_termination(self, value: bool) -> Self
pub fn forced_reconnect(&self) -> Option<bool>
pub fn forced_reconnect(&self) -> Option<bool>
Forced reconnect mode
pub fn with_forced_reconnect(self, value: bool) -> Self
pub fn reconnect_max_tries(&self) -> Option<i32>
pub fn reconnect_max_tries(&self) -> Option<i32>
Reconnect max tries
pub fn with_reconnect_max_tries(self, value: i32) -> Self
pub fn with_reconnect_max_tries(self, value: i32) -> Self
Set reconnect max tries
pub fn reconnect_interval(&self) -> Option<i32>
pub fn reconnect_interval(&self) -> Option<i32>
Reconnect interval in milliseconds
pub fn with_reconnect_interval(self, value: i32) -> Self
pub fn with_reconnect_interval(self, value: i32) -> Self
Set reconnect interval in milliseconds
pub fn with_log_dir(self, value: impl Into<String>) -> Self
pub fn with_log_dir(self, value: impl Into<String>) -> Self
Set log directory for FIX messages
pub fn to_engine_params(&self) -> UniquePtr<SessionExtraParameters>
pub fn to_engine_params(&self) -> UniquePtr<SessionExtraParameters>
Convert to Engine::SessionExtraParameters (C++ opaque type) This is used when passing parameters to the C++ engine, matching Python’s toSessionParameters()
Creates a C++ SessionExtraParameters object from the properties HashMap. The returned object is opaque to Rust but can be passed to C++ engine functions.
Example
use fixantenna_bindings::fixsessionparametersproxy_cxx::FixSessionParametersProxy;
let params = FixSessionParametersProxy::new()
.with_host("localhost")
.with_port(9999)
.with_user_name("trader");
let cpp_params = params.to_engine_params();
// cpp_params is UniquePtr<SessionExtraParameters> (opaque C++ object)
// Can be passed to engine.createSession() or other C++ functionsTrait Implementations
impl Clone for FixSessionParametersProxy
impl Clone for FixSessionParametersProxy
fn clone(&self) -> FixSessionParametersProxy
fn clone(&self) -> FixSessionParametersProxy
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more